@@ -144,8 +144,8 @@ namespace Ioad {
     template <typename T> T get_attribute(const std::string &attribute_name);
 
     template <typename T> void put_data(void *data, const std::string &encoded_name) const;
-    template <typename T, typename = typename std::enable_if<
-                              !std::is_base_of<Ioss::EntitySet, T>::value, T>::type>
+    template <typename T,
+              typename = typename std::enable_if_t<!std::is_base_of_v<Ioss::EntitySet, T>, T>>
     void put_var_type(const Ioss::Field &field, const std::string &encoded_name,
                       bool transformed_field) const;
     template <typename T>
@@ -200,11 +200,10 @@ namespace Ioad {
                                               const std::string   &var_name) const;
 
     template <typename T>
-    using IsIossEntityBlock =
-        typename std::enable_if<std::is_base_of<Ioss::EntityBlock, T>::value>::type;
+    using IsIossEntityBlock = typename std::enable_if_t<std::is_base_of_v<Ioss::EntityBlock, T>>;
     template <typename T>
     using IsNotIossEntityBlock =
-        typename std::enable_if<!std::is_base_of<Ioss::EntityBlock, T>::value>::type;
+        typename std::enable_if_t<!std::is_base_of_v<Ioss::EntityBlock, T>>;
 
     template <typename T, typename = IsIossEntityBlock<T>>
     void define_entity_meta_variables(const std::string &encoded_name);
