@@ -1,4 +1,4 @@
-// Copyright(C) 1999-2023 National Technology & Engineering Solutions
+// Copyright(C) 1999-2024 National Technology & Engineering Solutions
 // of Sandia, LLC (NTESS).  Under the terms of Contract DE-NA0003525 with
 // NTESS, the U.S. Government retains certain rights in this software.
 //
@@ -65,27 +65,27 @@ namespace Iocgns {
     // unsigned int with the supported Ioss::EntityTypes or'ed
     // together. If "return_value & Ioss::EntityType" is set, then the
     // database supports that type (e.g. return_value & Ioss::FACESET)
-    unsigned entity_field_support() const override;
+    IOSS_NODISCARD unsigned entity_field_support() const override;
 
     ~DatabaseIO() override;
 
-    std::string get_format() const override { return "CGNS"; }
+    IOSS_NODISCARD std::string get_format() const override { return "CGNS"; }
 
     // This isn't quite true since a CGNS library with cgsize_t == 64-bits can read
     // a file with 32-bit ints. However,...
-    int int_byte_size_db() const override { return CG_SIZEOF_SIZE; }
+    IOSS_NODISCARD int int_byte_size_db() const override { return CG_SIZEOF_SIZE; }
 
-    bool node_major() const override { return false; }
+    IOSS_NODISCARD bool node_major() const override { return false; }
 
     // Metadata-related functions.
     void write_meta_data();
     void write_results_meta_data();
 
-    int get_file_pointer() const override;
+    IOSS_NODISCARD int get_file_pointer() const override;
 
   private:
-    int64_t node_global_to_local_nl(int64_t global, bool must_exist) const override;
-    int64_t element_global_to_local_nl(int64_t global) const override;
+    IOSS_NODISCARD int64_t node_global_to_local_nl(int64_t global, bool must_exist) const override;
+    IOSS_NODISCARD int64_t element_global_to_local_nl(int64_t global) const override;
 
     void read_meta_data_nl() override;
 
@@ -95,12 +95,12 @@ namespace Iocgns {
     void openDatabase_nl() const override;
     void closeDatabase_nl() const override;
 
-    bool begin_nl(Ioss::State state) override;
-    bool end_nl(Ioss::State state) override;
+    IOSS_NODISCARD bool begin_nl(Ioss::State state) override;
+    IOSS_NODISCARD bool end_nl(Ioss::State state) override;
 
-    bool begin_state_nl(int state, double time) override;
-    bool end_state_nl(int state, double time) override;
-    void flush_database_nl() const override;
+    IOSS_NODISCARD bool begin_state_nl(int state, double time) override;
+    IOSS_NODISCARD bool end_state_nl(int state, double time) override;
+    void                flush_database_nl() const override;
 
     bool   check_valid_file_open(int status) const;
     void   create_structured_block(int base, int zone, size_t &num_node);
@@ -195,9 +195,10 @@ namespace Iocgns {
                                       void *data, size_t data_size) const;
 
     // ID Mapping functions.
-    const Ioss::Map &get_map(entity_type type) const;
-    const Ioss::Map &get_map(Ioss::Map &entity_map, int64_t entityCount, int64_t file_offset,
-                             int64_t file_count, entity_type type) const;
+    IOSS_NODISCARD const Ioss::Map &get_map(entity_type type) const;
+    IOSS_NODISCARD const Ioss::Map &get_map(Ioss::Map &entity_map, int64_t entityCount,
+                                            int64_t file_offset, int64_t file_count,
+                                            entity_type type) const;
 
     mutable int m_cgnsFilePtr{-1};
     mutable int m_cgnsBasePtr{
